package com.eactive.eai.rms.bat.manage.comm.property;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.springframework.stereotype.Repository;

import com.eactive.eai.rms.common.base.SqlMapClientTemplateDao;

@Repository("batPropertyDao")
@SuppressWarnings({"deprecation","unchecked"})
public class BatPropertyDao extends SqlMapClientTemplateDao {

	public int selectListCount(HashMap<String, Object> param) throws Exception {
    	return (Integer)template.queryForObject("BatProperty.selectListCount", param);
    }	

	public List<Map<String, Object>> selectList(HashMap<String, Object> param) throws Exception {
    	return (List<Map<String, Object>>)template.queryForList("BatProperty.selectList", param);
    }	

	public HashMap<String, Object> propertyGroupDetail(HashMap<String, Object> param) throws Exception {
    	return (HashMap<String, Object>)template.queryForObject("BatProperty.propertyGroupDetail", param);
    }	

	public List<Map<String, Object>> propertyDetail(HashMap<String, Object> param) throws Exception {
    	return (List<Map<String, Object>>)template.queryForList("BatProperty.propertyDetail", param);
    }	

	public HashMap<String, Object> getProperties(HashMap<String, Object> param) throws Exception {
    	return (HashMap<String, Object>)template.queryForObject("BatProperty.getProperties", param);
    }
	
    public void insert(HashMap<String, Object> paramMap) throws Exception{
        this.template.insert("BatProperty.insert", paramMap);
    }      

    public void insertProperty(HashMap<String, Object> paramMap) throws Exception{
        this.template.insert("BatProperty.insertProperty", paramMap);
    }      
    
    public void update(HashMap<String, Object> paramMap) throws Exception{
        this.template.update("BatProperty.update", paramMap);
    }

    public void delete(HashMap<String, Object> paramMap) throws Exception{
        this.template.delete("BatProperty.delete", paramMap);
    }

    public void deleteProperty(HashMap<String, Object> paramMap) throws Exception{
        this.template.delete("BatProperty.deleteProperty", paramMap);
    }
}